==> haskell-http-client-restricted-0.1.0-16-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-http-client-restricted.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 http-client-restricted
version:              0.1.0
visibility:           public
id:                   http-client-restricted-0.1.0-3W7rHrwPmfbAYdJvJBYEQa
key:                  http-client-restricted-0.1.0-3W7rHrwPmfbAYdJvJBYEQa
license:              MIT
copyright:            2018 Joey Hess, 2013 Michael Snoyman
maintainer:           Joey Hess <id@joeyh.name>
author:               Joey Hess
synopsis:             restricting the servers that http-client will use
description:
    Addition to the http-client and http-client-tls
    libraries, that restricts the HTTP servers that can be used.

    This is useful when a security policy needs to eg, prevent connections to
    HTTP servers on localhost or a local network, or only allow connections
    to a specific HTTP server.

    It handles restricting redirects as well as the initial HTTP connection,
    and it also guards against DNS poisoning attacks.

category:             Network
abi:                  35e014aeb009854f56919b9e4a521f9c
exposed:              True
exposed-modules:      Network.HTTP.Client.Restricted
import-dirs:          /usr/lib/ghc-9.2.8/site-local/http-client-restricted-0.1.0
library-dirs:         /usr/lib/ghc-9.2.8/site-local/http-client-restricted-0.1.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-http-client-restricted
hs-libraries:         HShttp-client-restricted-0.1.0-3W7rHrwPmfbAYdJvJBYEQa
depends:
    base-4.16.4.0 crypton-connection-0.3.2-5fbU10HgbouBeTpIgRb8kx
    data-default-0.7.1.1-LSJh75QrCu1H2SWBLBb1YB
    http-client-0.7.15-GFtj4cUUjxDGnZKaI4AjE1
    http-client-tls-0.3.6.3-Fff9bfaN1MF9yyJi1Y1Qgj
    network-3.1.4.0-2VaTeXEywlqHC2pV2iXMik
    network-bsd-2.8.1.0-8odhSoml6qLDJTfWl3Ma9Z
    utf8-string-1.0.2-9i4m1tpDbmh81tMCrQ25jI

haddock-interfaces:
    /usr/share/doc/haskell-http-client-restricted/html/http-client-restricted.haddock

haddock-html:         /usr/share/doc/haskell-http-client-restricted/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-http-client-restricted-0.1.0-28-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-http-client-restricted.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 http-client-restricted
version:              0.1.0
visibility:           public
id:                   http-client-restricted-0.1.0-FnUVoQl45mELjfI8WPGdVp
key:                  http-client-restricted-0.1.0-FnUVoQl45mELjfI8WPGdVp
license:              MIT
copyright:            2018 Joey Hess, 2013 Michael Snoyman
maintainer:           Joey Hess <id@joeyh.name>
author:               Joey Hess
synopsis:             restricting the servers that http-client will use
description:
    Addition to the http-client and http-client-tls
    libraries, that restricts the HTTP servers that can be used.

    This is useful when a security policy needs to eg, prevent connections to
    HTTP servers on localhost or a local network, or only allow connections
    to a specific HTTP server.

    It handles restricting redirects as well as the initial HTTP connection,
    and it also guards against DNS poisoning attacks.

category:             Network
abi:                  9dab527d04f8e02031fcfe8de7c01191
exposed:              True
exposed-modules:      Network.HTTP.Client.Restricted
import-dirs:          /usr/lib/ghc-9.2.8/site-local/http-client-restricted-0.1.0
library-dirs:         /usr/lib/ghc-9.2.8/site-local/http-client-restricted-0.1.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-http-client-restricted
hs-libraries:         HShttp-client-restricted-0.1.0-FnUVoQl45mELjfI8WPGdVp
depends:
    base-4.16.4.0 crypton-connection-0.3.2-8RDci5jYdVsE9mwX2blZ3c
    data-default-0.7.1.1-JYvfHll1aet2HYdPlRdwv9
    http-client-0.7.15-15pF87z30Lb260fGpQvD7x
    http-client-tls-0.3.6.3-7PKwybeQpZP3STjfZ1Ty3Q
    network-3.1.4.0-BwapeZNENJRGd3a4t7iBSJ
    network-bsd-2.8.1.0-1Y5x0mszWxhBcPjCNBOVSm
    utf8-string-1.0.2-AQMRv3gsvE14uh4nlO1egX

haddock-interfaces:
    /usr/share/doc/haskell-http-client-restricted/html/http-client-restricted.haddock

haddock-html:         /usr/share/doc/haskell-http-client-restricted/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
